from setuptools import setup,find_packages

setup(
    name="akasj",
    version="0.0.1",
    author="ShiLuYao",
    description="Hello Word",
    # 你要安装的包，通过 setuptools.find_packages 找到当前目录下有哪些包
    packages=find_packages()
)
